@@ -2,7 +2,7 @@
 #' @keywords internal
 check_optional_deps <- function() {
   required_suggests <- c("ggforce", "ggeffects", "geosphere", "scales", "purrr", "future", "furrr", "parallel", "MuMIn", "MASS", "rmarkdown", "curl",
-                         "rstudioapi", "gstat", "sf", "sp", "spdep", "magick", "pryr", "httr")  # Remove "other_package"
+                         "rstudioapi", "gstat", "sf", "sp", "spdep", "magick", "httr")  # Remove "other_package"
 
   missing <- required_suggests[!sapply(required_suggests, requireNamespace, quietly = TRUE)]
 
